# 更新日志

## [1.0.2]

### Fixed

- 解决只有一个筛选字段时无法出现查询按钮的问题
- 解决初始化配置后，更新面板点重置再点更新导致筛选字段丢失的问题

## [1.0.1]

### Added

- 允许使用`./manage.py collectstatic`的方式部署
- 自动使用`settings.MEDIA_ROOT`作文件上传目录，没设置则默认在当前目录自动建立`lightning-files`子目录用作文件上传

## [1.0.0]

### Added

- Lightning正式版
